@@ -26,11 +26,11 @@ DBS = {
     'main': {
         'migrations': 'db/postgresql/main',
         'shards': [{
-            'host': host,
+            'host': ','.join(HOSTS),
             'dbname': cfg('pg.db'),
             'user': cfg('pg.user'),
             'password': cfg('pg.pass'),
-        } for host in HOSTS],
+        }],
         'recheck_timeout': 15,
         'pool_min_size': 10,
         'pool_max_size': 10,
